MailingLogger
=============

|CircleCI|_ |Docs|_

.. |CircleCI| image:: https://circleci.com/gh/simplistix/mailinglogger.svg?style=shield
.. _CircleCI: https://circleci.com/gh/simplistix/mailinglogger/tree/master

.. |Docs| image:: https://readthedocs.org/projects/mailinglogger/badge/?version=latest
.. _Docs: http://mailinglogger.readthedocs.org/en/latest/

This package provides more flexible and powerful email log handling for
python's standard logging framework.
